Prints a representation of the call graph for profile data produced
by Rprof. Output can be directed to a connection or a file.
printProfileCallGraph(pd, file = stdout(), percent = TRUE, GC = TRUE,
maxnodes = NA, total.pct = 0)Used for side effect.
profile data as returned by readProfileData.
a connection or the name of the file where the profile graph will be written.
logical; if true use percent of total time; otherwise use time in seconds
logical; include GC information or not.
integer; maximal number of nodes to use; nodes with lower total hit counts are dropped.
numeric; if positive, nodes with hit percentages below this level are dropped.
Luke Tierney
printProfileCallGraph produces a printed representation of
the call graph for profile data produced by Rprof. The
representation is analogous to the call graph produced by
gprof with a few minor changes. Eventually more complete
documentation of the format will be provided here; for now, reading
the gprof manual section on the call graph should help
understanding this output. The output is similar enough to
gprof output for the cgprof script to be able to produce a
visual representation of the call graph via Graphviz.
User manual for gprof, the GNU profiler.
cgprof: http://mvertes.free.fr/
Rprof,
summaryRprof,
flatProfile,
readProfileData,
plotProfileCallGraph,
profileCallGraph2Dot