Prints a Graphviz .dot file representation of the call graph for profile
data produced by Rprof.
profileCallGraph2Dot(pd, score = c("none", "total", "self"),
transfer = function(x) x, nodeColorMap = NULL,
edgeColorMap = NULL, filename = "Rprof.dot",
landscape = FALSE, mergeCycles = FALSE,
edgesColored = FALSE,
rankDir = c("TB", "LR"),
nodeDetails = FALSE, edgeDetails = FALSE,
nodeSizeScore = c("none", "total", "self"),
edgeSizeScore = c("none", "total"),
center = FALSE, size, shape = "ellipse",
layout = "dot", style, GC = TRUE,
maxnodes = NA, total.pct = 0)Used for side effect.
profile data as returned by readProfileData.
character string specifying whether to use total time or self time for coloring nodes/edges; no color used if missing.
function; maps score values in unit interval to unit interval
character vectors of color
specifications as produced by rainbow; transfer of
score is mapped to color
name of .dot file
logical; whether to add the rotate=90 option to
the .dot file
logical; whether to merge each cycle of recursion into a single node
logical; whether to color edges
character; value to use for the rankdir= option to
specify the direction that the plot is laid out using
the dot layout; must be either "TB" for
Top-to-Bottom or "LR" for Left-to-Right. The
default value is "LR".
logical; whether count information should be shown.
character; value to encode in the size of the nodes.
character; value to encode in the width of the edges.
logical; whether to add the center=1 option to
the .dot file.
character; string to add as size= option in the
.dot file.
character; node shape.
character; layout method to use.
named list of values for arguments score through
layout to use if not explicitly supplied.
logical; include GC information or not.
integer; maximal number of nodes to use; nodes with lower total hit counts are dropped.
numeric; if positive, nodes with hit percentages below this level are dropped.
Luke Tierney
Writes the call graph as a Graphviz .dot file. Color is used
to encode the fraction total or self time spent in each function or
call. The scores used correspond to the values in the printed
representation produced by printProfileCallGraph. For now,
see the gprof manual for further details. The color encoding
for a score s and a color map m is
ceiling(length(m) * transfer(s))
A style can be specified to set options to a set of cvalues that work well together.
User manual for gprof, the GNU profiler.
Graphviz: https://graphviz.gitlab.io/download/
Rprof,
summaryRprof,
readProfileData,
flatProfile,
plotProfileCallGraph,
printProfileCallGraph
plain.style
google.style