Learn R Programming

proftools (version 0.99-4)

readProfileData: Read Rprof Profile Data

Description

Reads in Rprof profile data for further processing.

Usage

readProfileData(filename = "Rprof.out")
readRStudioProfileCacheData()

Value

R representation of Rprof data,

Arguments

filename

Name of a file produced by Rprof()

Author

Luke Tierney

Details

readProfileData reads the data in the file produced by Rprof into a data structure for processing by other functions. The details of the structure are subject to change.

readRStudioProfileCacheData returns the data for the most recent profiling run in the RStudio profile cache, or NULL if no data is available.

See Also

Rprof, summaryRprof, flatProfile, plotProfileCallGraph, printProfileCallGraph, profileCallGraph2Dot

Examples

Run this code
pd <- readProfileData(system.file("samples", "glmEx.out", package="proftools"))
flatProfile(pd)
flatProfile(pd, FALSE)

Run the code above in your browser using DataLab