| styles | R Documentation |
Styles providing coordinated settings of display parameters for the
call graph display functions plotProfileCallGraph and
profileCallGraph2Dot.
plain.style
google.style
The plain.style style corresponds to the default parameter settings
in the display functions. It can be used as the basis for creating a
new custom style.
The google.style style is based on the display style used in the
pprof tool from the Google Performance Tools suite.
A list containing the following components:
layout |
The layout method to use: One of |
score |
character string specifying whether to use total time or self time for coloring nodes/edges; no color used if missing. |
transfer |
function; maps score values in unit interval to unit interval |
nodeColorMap, edgeColorMap |
character vectors of color
specifications as produced by |
mergeCycles |
logical; whether to merge each cycle of recursion into a single node |
edgesColored |
logical; whether to color edges |
rankDir |
The direction that the plot is laid out in, one of
either |
nodeDetails, edgeDetails |
logical; whether count information should be shown. |
nodeSizeScore |
character; value to encode in the size of the nodes. |
edgeSizeScore |
character; value to encode in the width of the edges. |
shape |
character; node shape. |
maxnodes |
integer; maximal number of nodes to use; nodes with lower total hit counts are dropped. |
total.pct |
numeric; if positive, nodes with hit percentages below this level are dropped. |
Luke Tierney
https://gperftools.github.io/gperftools/cpuprofile.html.
Rprof,
flatProfile,
summaryRprof,
readProfileData,
plotProfileCallGraph,
printProfileCallGraph,
profileCallGraph2Dot
pd <- readProfileData(system.file("samples", "glmEx.out", package="proftools"))
plotProfileCallGraph(pd, style = plain.style)
plotProfileCallGraph(pd, style = google.style)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.