Learn R Programming

proftools (version 0.99-4)

writeCallgrindFile: Write Out Profile Data in Callgrind Format

Description

Writes the profile data in callgrind format suitable for use with kcachegrind or qcachegrind.

Usage

writeCallgrindFile(pd, file = "Rprof.cg", GC = TRUE, dropSource = TRUE)

Value

Used for side effect.

Arguments

pd

profile data as returned by readProfileData.

file

a connection or the name of the file where the callgrind output will be written.

GC

logical; if true include GC information.

dropSource

logical; if true drop initial stack entried from a source call and add a top level marker.

Author

Luke Tierney

Details

The callgrind format is used by Valgrind's callgrind tool. The KDE tool kcachegrind can be used to display the file; kcachegrind displays the summary statistics, a call graph, and annotated source code if source information is available. kcachegrind is available in Linux and Windows; on Mac OSX qcachegrind is available.

See Also

Rprof, summaryRprof, flatProfile, readProfileData, plotProfileCallGraph, profileCallGraph2Dot