Writes the profile data in callgrind format suitable for use with
kcachegrind or qcachegrind.
writeCallgrindFile(pd, file = "Rprof.cg", GC = TRUE, dropSource = TRUE)Used for side effect.
profile data as returned by readProfileData.
a connection or the name of the file where the callgrind output will be written.
logical; if true include GC information.
logical; if true drop initial stack entried from a
source call and add a top level marker.
Luke Tierney
The callgrind format is used by Valgrind's callgrind tool. The KDE
tool kcachegrind can be used to display the file;
kcachegrind displays the summary statistics, a call graph, and
annotated source code if source information is
available. kcachegrind is available in Linux and Windows; on
Mac OSX qcachegrind is available.
Rprof,
summaryRprof,
flatProfile,
readProfileData,
plotProfileCallGraph,
profileCallGraph2Dot